.. _release_history:

Release and Version History
==============================================================================


x.y.z (Backlog)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**Features and Improvements**

**Minor Improvements**

**Bugfixes**

**Miscellaneous**


0.1.1 (2024-07-28)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**Features and Improvements**

- First release:
- Add the following Public APIs:
    - ``acore_soap.api.SOAPResponseParseError``
    - ``acore_soap.api.SOAPCommandFailedError``
    - ``acore_soap.api.SOAPRequest``
    - ``acore_soap.api.SOAPResponse``
    - ``acore_soap.api.gm.GMCommandRequest``
    - ``acore_soap.api.gm.GMCommandResponse``
    - ``acore_soap.api.gm.ServerInfoRequest``
    - ``acore_soap.api.gm.ServerInfoResponse``
    - ``acore_soap.api.gm.CreateAccountRequest``
    - ``acore_soap.api.gm.CreateAccountResponse``
    - ``acore_soap.api.gm.ChangeAccountPasswordRequest``
    - ``acore_soap.api.gm.ChangeAccountPasswordResponse``
    - ``acore_soap.api.gm.SetAccountPasswordRequest``
    - ``acore_soap.api.gm.SetAccountPasswordResponse``
    - ``acore_soap.api.gm.SetAccountGmlevelRequest``
    - ``acore_soap.api.gm.SetAccountGmlevelResponse``
    - ``acore_soap.api.gm.AddItemRequest``
    - ``acore_soap.api.gm.AddItemResponse``
